@@ -133,7 +133,7 @@ class select_geoms:
                 self.TestPlot = design_plot
         except AttributeError:
             sg.Popup("     Side length of the test plot is larger than required, wont have any Test plot for the AOI,\n     because test plot threshold length is bigger,\n\n     Please insert smaller length for the Test Plots")
-            self.TestPlot = None
+            self.geosolution = None
             pass
 
 class rotate_plot:
